# Abaqus Output Database

The Python ODB API commands are used to read and write data from an output database (.odb) file. The path to the Odb object can be via the session.odbs repository or via a variable. In this chapter the Access and Path statements refer to a variable called odb that represents an existing Odb object.

## Classes

### Odb

```{eval-rst}
.. autoclass:: abaqus.Odb.Odb.Odb
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbBase

```{eval-rst}
.. autoclass:: abaqus.Odb.OdbBase.OdbBase
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### AmplitudeOdb

```{eval-rst}
.. autoclass:: abaqus.Amplitude.AmplitudeOdb.AmplitudeOdb
    :members:
    :special-members: __init__
    :show-inheritance:
    :noindex:

    .. autoclasstoc::
```

### FilterOdb

```{eval-rst}
.. autoclass:: abaqus.Filter.FilterOdb.FilterOdb
    :members:
    :special-members: __init__
    :show-inheritance:
    :noindex:

    .. autoclasstoc::
```

### MaterialOdb

```{eval-rst}
.. autoclass:: abaqus.Material.MaterialOdb.MaterialOdb
    :members:
    :special-members: __init__
    :show-inheritance:
    :noindex:

    .. autoclasstoc::
```

### BeamSectionProfileOdb

```{eval-rst}
.. autoclass:: abaqus.BeamSectionProfile.BeamSectionProfileOdb.BeamSectionProfileOdb
    :members:
    :special-members: __init__
    :show-inheritance:
    :noindex:

    .. autoclasstoc::
```

### AnalyticSurface

```{eval-rst}
.. autoclass:: abaqus.Odb.AnalyticSurface.AnalyticSurface
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### AnalyticSurfaceSegment

```{eval-rst}
.. autoclass:: abaqus.Odb.AnalyticSurfaceSegment.AnalyticSurfaceSegment
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### BeamOrientation

```{eval-rst}
.. autoclass:: abaqus.Odb.BeamOrientation.BeamOrientation
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### BeamOrientationArray

```{eval-rst}
.. autoclass:: abaqus.Odb.BeamOrientationArray.BeamOrientationArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### FieldBulkData

```{eval-rst}
.. autoclass:: abaqus.Odb.FieldBulkData.FieldBulkData
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### FieldLocation

```{eval-rst}
.. autoclass:: abaqus.Odb.FieldLocation.FieldLocation
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### FieldLocationArray

```{eval-rst}
.. autoclass:: abaqus.Odb.FieldLocationArray.FieldLocationArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### FieldOutput

```{eval-rst}
.. autoclass:: abaqus.Odb.FieldOutput.FieldOutput
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### FieldValue

```{eval-rst}
.. autoclass:: abaqus.Odb.FieldValue.FieldValue
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### FieldValueArray

```{eval-rst}
.. autoclass:: abaqus.Odb.FieldValueArray.FieldValueArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### HistoryOutput

```{eval-rst}
.. autoclass:: abaqus.Odb.HistoryOutput.HistoryOutput
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### HistoryPoint

```{eval-rst}
.. autoclass:: abaqus.Odb.HistoryPoint.HistoryPoint
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### HistoryRegion

```{eval-rst}
.. autoclass:: abaqus.Odb.HistoryRegion.HistoryRegion
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### JobData

```{eval-rst}
.. autoclass:: abaqus.Odb.JobData.JobData
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbAssembly

```{eval-rst}
.. autoclass:: abaqus.Odb.OdbAssembly.OdbAssembly
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbAssemblyBase

```{eval-rst}
.. autoclass:: abaqus.Odb.OdbAssemblyBase.OdbAssemblyBase
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbCommands

```{eval-rst}
.. automodule:: abaqus.Odb.OdbCommands
    :members:
    :special-members: __init__
    :show-inheritance:
```

### OdbDatumCsys

```{eval-rst}
.. autoclass:: abaqus.Odb.OdbDatumCsys.OdbDatumCsys
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbFrame

```{eval-rst}
.. autoclass:: abaqus.Odb.OdbFrame.OdbFrame
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbFrameArray

```{eval-rst}
.. autoclass:: abaqus.Odb.OdbFrameArray.OdbFrameArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbInstance

```{eval-rst}
.. autoclass:: abaqus.Odb.OdbInstance.OdbInstance
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbInstanceBase

```{eval-rst}
.. autoclass:: abaqus.Odb.OdbInstanceBase.OdbInstanceBase
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbLoadCase

```{eval-rst}
.. autoclass:: abaqus.Odb.OdbLoadCase.OdbLoadCase
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbMeshElement

```{eval-rst}
.. autoclass:: abaqus.Odb.OdbMeshElement.OdbMeshElement
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbMeshElementArray

```{eval-rst}
.. autoclass:: abaqus.Odb.OdbMeshElementArray.OdbMeshElementArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbMeshNode

```{eval-rst}
.. autoclass:: abaqus.Odb.OdbMeshNode.OdbMeshNode
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbMeshNodeArray

```{eval-rst}
.. autoclass:: abaqus.Odb.OdbMeshNodeArray.OdbMeshNodeArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbPart

```{eval-rst}
.. autoclass:: abaqus.Odb.OdbPart.OdbPart
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbPartBase

```{eval-rst}
.. autoclass:: abaqus.Odb.OdbPartBase.OdbPartBase
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbPretensionSection

```{eval-rst}
.. autoclass:: abaqus.Odb.OdbPretensionSection.OdbPretensionSection
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbPretensionSectionArray

```{eval-rst}
.. autoclass:: abaqus.Odb.OdbPretensionSectionArray.OdbPretensionSectionArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbRigidBody

```{eval-rst}
.. autoclass:: abaqus.Odb.OdbRigidBody.OdbRigidBody
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbRigidBodyArray

```{eval-rst}
.. autoclass:: abaqus.Odb.OdbRigidBodyArray.OdbRigidBodyArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbSequenceAnalyticSurfaceSegment

```{eval-rst}
.. autoclass:: abaqus.Odb.OdbSequenceAnalyticSurfaceSegment.OdbSequenceAnalyticSurfaceSegment
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbSession

```{eval-rst}
.. autoclass:: abaqus.Odb.OdbSession.OdbSession
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbSet

```{eval-rst}
.. autoclass:: abaqus.Odb.OdbSet.OdbSet
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbStep

```{eval-rst}
.. autoclass:: abaqus.Odb.OdbStep.OdbStep
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbStepBase

```{eval-rst}
.. autoclass:: abaqus.Odb.OdbStepBase.OdbStepBase
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### RebarOrientation

```{eval-rst}
.. autoclass:: abaqus.Odb.RebarOrientation.RebarOrientation
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### RebarOrientationArray

```{eval-rst}
.. autoclass:: abaqus.Odb.RebarOrientationArray.RebarOrientationArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ScratchOdb

```{eval-rst}
.. autoclass:: abaqus.Odb.ScratchOdb.ScratchOdb
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SectionCategory

```{eval-rst}
.. autoclass:: abaqus.Odb.SectionCategory.SectionCategory
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SectionPoint

```{eval-rst}
.. autoclass:: abaqus.Odb.SectionPoint.SectionPoint
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SectionPointArray

```{eval-rst}
.. autoclass:: abaqus.Odb.SectionPointArray.SectionPointArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SectorDefinition

```{eval-rst}
.. autoclass:: abaqus.Odb.SectorDefinition.SectorDefinition
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### UserData

```{eval-rst}
.. autoclass:: abaqus.Odb.UserData.UserData
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### UserDataBase

```{eval-rst}
.. autoclass:: abaqus.Odb.UserDataBase.UserDataBase
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```
